/**********************************************************************************************************************					
Instituto Nacional de Estadstica (INE) www.ine.es					
***********************************************************************************************************************					
					
DESCRIPCIN:					
Este programa genera un fichero SAS con formatos, partiendo de un fichero sin ellos.					
					
Consta de las siguientes partes:					
	* 1. Definir la librera de trabajo --> Libname				
	* 2. Definicin de formatos --> PROC FORMAT				
	* 3. Vincular formatos a la base de datos --> PASO data				
					
 Entrada:                                                           					
     - Fichero SAS sin formatos: 	 EGHE_2019.sas7bdat				
 Salida:                                                           					
     - Fichero SAS con formatos: 	 EGHE_2019_conFormato.sas7bdat				
					
Donde:					
	* Operacin: Encuesta de gasto de los hogares en educacin_EGHE				
	* Curso: 2019-20				
					
************************************************************************************************************************/					
					
/*1) Definir la librera de trabajo: introducir el directorio que desee como librera					
(se da como ejemplo 'C:\Mis resultados'), y copiar en ese directorio el fichero sas "EGHE_2019.sas7bdat"*/					
					
libname ROutput 'C:\Mis resultados';					

options fmtsearch = (ROutput ROutput.cat1);

* 2) DEFINICIN DE FORMATOS;
PROC FORMAT LIBRARY=ROutput.cat1;
value $TSEXO

"1"="Hombre"
"2"="Mujer"
;
value $TAMUNI

"1"="Menos de 10.000 habitantes"
"2"="De 10.000 a 49.999 habitantes"
"3"="De 50.000 a 99.999 habitantes"
"4"="De 100.000 a 499.999 habitantes"
"5"="Ms de 500.000 habitantes"
;
value $TNACION

"1"="Espaola"
"2"="Extranjera"
"3"="Doble nacionalidad"
;
value $T0SINO

"1"="Si"
"0"="No"
;
value $T2SINO

"1"="Si"
"2"="No"
;
value $T1ESTU

"1"="Educacin Infantil"
"2"="Educacin Primaria"
"3"="Educacin Secundaria"
"4"="Educacin Superior"
"5"="Otros estudios (sin nivel acadmico)"
"0"="No realiza estudios"
;
value $T2ESTU

"01"="1 Ciclo de Educacin Infantil"
"02"="2 Ciclo de Educacin Infantil"
"03"="Educacin Primaria"
"04"="Educacin Secundaria Obligatoria (ESO)"
"05"="Bachillerato"
"06"="Ciclos Formativos de FP"
"07"="Otros estudios de educacin secundaria"
"08"="Estudios Universitarios"
"09"="Ciclos Formativos de Grado Superior"
"10"="Otros estudios de educacin superior"
"11"="Otros estudios (sin nivel acadmico)"
"00"="No realiza estudios"
;
value $TENSE

"1"="Enseanza Pblica"
"2"="Enseanza Concertada"
"3"="Enseanza Privada"
;
value $T1LOCAL

"1"="En el mismo municipio de residencia"
"2"="En otro municipio de la misma provincia"
"3"="En otra provincia de la misma Comunidad Autnoma"
"4"="En otra Comunidad Autnoma"
"5"="En el extranjero"
;
value $T2LOCAL

"1"="En un pas de la Unin Europea"
"2"="En otro pas de Europa (no UE)"
"3"="En Estados Unidos"
"4"="En otro pas de Amrica"
"5"="En el resto del mundo"
;



* 3) VINCULAR FORMATOS A LA BASE DE DATOS;
data ROutput.EGHE_2019_ConFormato;
	set ROutput.EGHE_2019;

FORMAT TMUNI $TAMUNI.;
FORMAT SEXO $TSEXO.;
FORMAT NACIONALIDAD $TNACION.;
FORMAT ESTUDIANTE $T0SINO.;
FORMAT REGLADO $T0SINO.;
FORMAT NOREGLADO $T0SINO.;
FORMAT NEST $T1ESTU.;
FORMAT NEST2 $T2ESTU.;
FORMAT C01 $TENSE.;
FORMAT C03 $T1LOCAL.;
FORMAT C04 $T2LOCAL.;
FORMAT C08 $T2SINO.;
FORMAT C10 $T2SINO.;
FORMAT C12 $T2SINO.;
FORMAT C14 $T2SINO.;
FORMAT C16 $T2SINO.;
FORMAT C18 $T2SINO.;
FORMAT C20 $T2SINO.;
FORMAT C22 $T2SINO.;
FORMAT C24 $T2SINO.;
FORMAT C26 $T2SINO.;
FORMAT DLIB $T2SINO.;
FORMAT D42 $T2SINO.;
FORMAT D44 $T2SINO.;
FORMAT D47 $T2SINO.;
FORMAT D50 $T2SINO.;
FORMAT D53 $T2SINO.;
FORMAT D56 $T2SINO.;
FORMAT E59 $T2SINO.;
FORMAT E60R1 $T2SINO.;
FORMAT E60R2 $T2SINO.;
FORMAT E60R3 $T2SINO.;
FORMAT E60R4 $T2SINO.;
FORMAT E60R5 $T2SINO.;
FORMAT E60R6 $T2SINO.;
FORMAT E61R1 $T2SINO.;
FORMAT E61R2 $T2SINO.;
FORMAT E61R3 $T2SINO.;
FORMAT E61R4 $T2SINO.;
FORMAT E61R5 $T2SINO.;
FORMAT E61R6 $T2SINO.;
FORMAT E61R7 $T2SINO.;
FORMAT E62R1 $T2SINO.;
FORMAT E62R2 $T2SINO.;
FORMAT E62R3 $T2SINO.;
FORMAT E62R4 $T2SINO.;



RUN;
/* FIN PROGRAMA: Microdatos en SAS: EGHE_2019.sas*/
